.. _cli:

Command line interface
++++++++++++++++++++++

This tooling is a bit sparse right now.
Perhaps other useful helpers will be identified in the future.

.. click:: qts._cli:main
   :prog: qts
   :nested: full
